# This file is part of the Django-fatpages project, and thus being
# redistributed under the same terms, ie.: the GPL v3 license.
# See LICENSE files for more details
"""
the 'render' tag will render content using appropriate markup.
"""

from django import template
from django.template import defaultfilters
from django.contrib.markup.templatetags.markup import markdown, textile, restructuredtext

filter_dict = {
    'textile': textile,
    'markdown': markdown,
    'restructuredtext': restructuredtext
}

register = template.Library()

def render(page_object):

    if page_object.markup in filter_dict:
        return filter_dict[page_object.markup](page_object.content).strip()
    elif page_object.markup == 'linebreaks':
        return defaultfilters.linebreaks(page_object.content).strip()
    else:
        return page_object.content

register.filter('render', render)
